@@ -5,7 +5,7 @@ print_item_list affiche les éléments d'une liste contenant ou pas
 des listes.
 """
 
-def print_item_list(ma_liste, niveau):
+def print_item_list(ma_liste, niveau=0):
 	"""
 	print_item_list() prend en argument "ma_liste",
 	ma_liste  est une liste python. Chaque element de "ma_liste" 
